From 69bb61786295891ebbf918384aefea977215d869 Mon Sep 17 00:00:00 2001
From: Justin Pryzby <pryzbyj@telsasoft.com>
Date: Sun, 28 Nov 2021 18:52:58 -0600
Subject: [PATCH 03/10] guc.c: do not mention units..

Since values can be specified in other units.  The specified units are the
default when no unit is specified.

Note that PRESET options are an exception: they're used for output only,
so the description *should* include units...
---
 src/backend/utils/misc/guc.c | 28 ++++++++++++++--------------
 1 file changed, 14 insertions(+), 14 deletions(-)

diff --git a/src/backend/utils/misc/guc.c b/src/backend/utils/misc/guc.c
index 3abd370f9f..96abcfaf90 100644
--- a/src/backend/utils/misc/guc.c
+++ b/src/backend/utils/misc/guc.c
@@ -2132,7 +2132,7 @@ static struct config_int ConfigureNamesInt[] =
 	{
 		{"archive_timeout", PGC_SIGHUP, WAL_ARCHIVING,
 			gettext_noop("Forces a switch to the next WAL file if a "
-						 "new file has not been started within N seconds."),
+						 "new file has not been started within this period of time."),
 			NULL,
 			GUC_UNIT_S
 		},
@@ -2142,7 +2142,7 @@ static struct config_int ConfigureNamesInt[] =
 	},
 	{
 		{"post_auth_delay", PGC_BACKEND, DEVELOPER_OPTIONS,
-			gettext_noop("Waits N seconds on connection startup after authentication."),
+			gettext_noop("Waits this period of time on connection startup after authentication."),
 			gettext_noop("This allows attaching a debugger to the process."),
 			GUC_NOT_IN_SAMPLE | GUC_UNIT_S
 		},
@@ -2468,7 +2468,7 @@ static struct config_int ConfigureNamesInt[] =
 	 */
 	{
 		{"max_stack_depth", PGC_SUSET, RESOURCES_MEM,
-			gettext_noop("Sets the maximum stack depth, in kilobytes."),
+			gettext_noop("Sets the maximum stack depth."),
 			NULL,
 			GUC_UNIT_KB
 		},
@@ -2759,7 +2759,7 @@ static struct config_int ConfigureNamesInt[] =
 	{
 		/* Not for general use */
 		{"pre_auth_delay", PGC_SIGHUP, DEVELOPER_OPTIONS,
-			gettext_noop("Waits N seconds on connection startup before authentication."),
+			gettext_noop("Waits this period of time on connection startup before authentication."),
 			gettext_noop("This allows attaching a debugger to the process."),
 			GUC_NOT_IN_SAMPLE | GUC_UNIT_S
 		},
@@ -3003,7 +3003,7 @@ static struct config_int ConfigureNamesInt[] =
 
 	{
 		{"log_parameter_max_length", PGC_SUSET, LOGGING_WHAT,
-			gettext_noop("When logging statements, limit logged parameter values to first N bytes."),
+			gettext_noop("When logging statements, limit logged parameter values to this length."),
 			gettext_noop("-1 to print values in full."),
 			GUC_UNIT_BYTE
 		},
@@ -3014,7 +3014,7 @@ static struct config_int ConfigureNamesInt[] =
 
 	{
 		{"log_parameter_max_length_on_error", PGC_USERSET, LOGGING_WHAT,
-			gettext_noop("When reporting an error, limit logged parameter values to first N bytes."),
+			gettext_noop("When reporting an error, limit logged parameter values to this length."),
 			gettext_noop("-1 to print values in full."),
 			GUC_UNIT_BYTE
 		},
@@ -3141,7 +3141,7 @@ static struct config_int ConfigureNamesInt[] =
 
 	{
 		{"log_rotation_age", PGC_SIGHUP, LOGGING_WHERE,
-			gettext_noop("Automatic log file rotation will occur after N minutes."),
+			gettext_noop("Automatic log file rotation will occur after this period of time."),
 			NULL,
 			GUC_UNIT_MIN
 		},
@@ -3152,7 +3152,7 @@ static struct config_int ConfigureNamesInt[] =
 
 	{
 		{"log_rotation_size", PGC_SIGHUP, LOGGING_WHERE,
-			gettext_noop("Automatic log file rotation will occur after N kilobytes."),
+			gettext_noop("Automatic log file rotation will occur when the log exceeds this size."),
 			NULL,
 			GUC_UNIT_KB
 		},
@@ -3196,7 +3196,7 @@ static struct config_int ConfigureNamesInt[] =
 
 	{
 		{"block_size", PGC_INTERNAL, PRESET_OPTIONS,
-			gettext_noop("Shows the size of a disk block in bytes."),
+			gettext_noop("Shows the size of a disk block."),
 			NULL,
 			GUC_NOT_IN_SAMPLE | GUC_DISALLOW_IN_FILE | GUC_UNIT_BYTE
 		},
@@ -3218,7 +3218,7 @@ static struct config_int ConfigureNamesInt[] =
 
 	{
 		{"wal_block_size", PGC_INTERNAL, PRESET_OPTIONS,
-			gettext_noop("Shows the block size of the write ahead log in bytes."),
+			gettext_noop("Shows the block size of the write ahead log."),
 			NULL,
 			GUC_NOT_IN_SAMPLE | GUC_DISALLOW_IN_FILE | GUC_UNIT_BYTE
 		},
@@ -3480,7 +3480,7 @@ static struct config_int ConfigureNamesInt[] =
 
 	{
 		{"log_temp_files", PGC_SUSET, LOGGING_WHAT,
-			gettext_noop("Log the use of temporary files larger than this number of kilobytes."),
+			gettext_noop("Log the use of temporary files larger than this size."),
 			gettext_noop("Zero logs all files. The default is -1 (turning this feature off)."),
 			GUC_UNIT_KB
 		},
@@ -3491,7 +3491,7 @@ static struct config_int ConfigureNamesInt[] =
 
 	{
 		{"track_activity_query_size", PGC_POSTMASTER, STATS_COLLECTOR,
-			gettext_noop("Sets the size reserved for pg_stat_activity.query, in bytes."),
+			gettext_noop("Sets the size reserved for pg_stat_activity.query."),
 			NULL,
 			GUC_UNIT_BYTE
 		},
@@ -3767,7 +3767,7 @@ static struct config_real ConfigureNamesReal[] =
 
 	{
 		{"vacuum_cost_delay", PGC_USERSET, RESOURCES_VACUUM_DELAY,
-			gettext_noop("Vacuum cost delay in milliseconds."),
+			gettext_noop("Vacuum cost delay."),
 			NULL,
 			GUC_UNIT_MS
 		},
@@ -3778,7 +3778,7 @@ static struct config_real ConfigureNamesReal[] =
 
 	{
 		{"autovacuum_vacuum_cost_delay", PGC_SIGHUP, AUTOVACUUM,
-			gettext_noop("Vacuum cost delay in milliseconds, for autovacuum."),
+			gettext_noop("Vacuum cost delay, for autovacuum."),
 			NULL,
 			GUC_UNIT_MS
 		},
-- 
2.17.0

